package cn.com.qmth.examcloud.support.util;

import cn.com.qmth.examcloud.commons.exception.StatusException;
import org.apache.commons.lang3.StringUtils;

import java.io.*;
import java.net.HttpURLConnection;
import java.net.URL;

public class FileUtil {

    /**
     * 将网络文件保存到本地
     *
     * @param fileUrl   网络文件URL
     * @param localFile 本地文件对象
     * @throws IOException
     */
    public static void saveUrlAs(String fileUrl, File localFile) {
        if (StringUtils.isBlank(fileUrl)) {
            throw new StatusException("500", "文件链接为空");
        }
        if (!fileUrl.toLowerCase().startsWith("http") && !fileUrl.toLowerCase().startsWith("https")) {
            throw new StatusException("500", "文件链接不是URL");
        }
        try {
            saveUrlAs(fileUrl, localFile.getAbsolutePath());
        } catch (IOException e) {
            throw new StatusException("5001", "下载文件出错", e);
        }
    }

    /**
     * 将网络文件保存到本地
     *
     * @param fileUrl       网络文件URL
     * @param localFilePath 例如D:/123.txt
     * @throws IOException
     */
    private static void saveUrlAs(String fileUrl, String localFilePath) throws IOException {
        URL url = new URL(fileUrl);

        HttpURLConnection connection;
        connection = (HttpURLConnection) url.openConnection();

        try (DataInputStream dataInputStream = new DataInputStream(connection.getInputStream());
                FileOutputStream fileOutputStream = new FileOutputStream(localFilePath);
                DataOutputStream dataOutputStream = new DataOutputStream(fileOutputStream);) {

            byte[] buffer = new byte[4096];
            int count;
            while ((count = dataInputStream.read(buffer)) > 0) {
                dataOutputStream.write(buffer, 0, count);
            }
            fileOutputStream.flush();
            dataOutputStream.flush();
        } finally {
            if (connection != null) {
                connection.disconnect();
            }
        }
    }

}
